@@ -26,7 +26,6 @@ from wavespeed_mcp.utils import (
     process_image_input,
     is_english_text,
 )
-from wavespeed_mcp.schema_utils import create_compliant_schema
 from wavespeed_mcp.const import (
     DEFAULT_IMAGE_SIZE,
     DEFAULT_NUM_INFERENCE_STEPS,
@@ -81,29 +80,8 @@ if not api_key:
 
 # Initialize MCP server and API client
 mcp = FastMCP(
-    "WaveSpeed", 
-    log_level=os.getenv(ENV_FASTMCP_LOG_LEVEL, DEFAULT_LOG_LEVEL)
+    "WaveSpeed", log_level=os.getenv(ENV_FASTMCP_LOG_LEVEL, DEFAULT_LOG_LEVEL)
 )
-
-# Custom tool decorator that ensures JSON Schema 2020-12 compliance
-def compliant_tool(description: str):
-    """Decorator to create JSON Schema 2020-12 compliant tools."""
-    def decorator(func):
-        # Generate compliant schema
-        input_schema = create_compliant_schema(func)
-        
-        # Use FastMCP's tool decorator but override the schema
-        tool_decorator = mcp.tool(description=description)
-        decorated_func = tool_decorator(func)
-        
-        # Override the generated schema with our compliant one
-        tool_name = func.__name__
-        if hasattr(mcp, '_tools') and tool_name in mcp._tools:
-            mcp._tools[tool_name].inputSchema = input_schema
-        
-        return decorated_func
-    return decorator
-
 api_client = WavespeedAPIClient(api_key, f"{api_host}{API_BASE_PATH}/{API_VERSION}")
 
 
@@ -138,15 +116,6 @@ class WaveSpeedResult(BaseModel):
         return json.dumps(self.model_dump(), indent=2)
 
 
-class LoraConfig(BaseModel):
-    """Configuration for a single LoRA model."""
-
-    path: str
-    scale: float = 1.0
-
-
-
-
 def _process_wavespeed_request(
     api_endpoint: str,
     payload: dict,
@@ -345,7 +314,7 @@ def get_video_models(model):
     return model
 
 
-@compliant_tool(
+@mcp.tool(
     description="""Generate an image from text prompt using WaveSpeed AI.
 
     Args:
@@ -386,14 +355,14 @@ def get_video_models(model):
 def text_to_image(
     prompt: str,
     model: Optional[str] = None,
-    loras: Optional[List[LoraConfig]] = None,
+    loras: Optional[List[Dict[str, Union[str, float]]]] = None,
     size: str = DEFAULT_IMAGE_SIZE,
     num_inference_steps: int = DEFAULT_NUM_INFERENCE_STEPS,
     guidance_scale: float = DEFAULT_GUIDANCE_SCALE,
     num_images: int = DEFAULT_NUM_IMAGES,
     seed: int = DEFAULT_SEED,
     enable_safety_checker: bool = True,
-    output_directory: Optional[str] = None,
+    output_directory: str = None,
 ):
     """Generate an image from text prompt using WaveSpeed AI."""
 
@@ -414,19 +383,14 @@ def text_to_image(
 
     # Validate and set default loras if not provided
     if not loras:
-        loras_dicts = [DEFAULT_IMAGE_LORA]
+        loras = [DEFAULT_IMAGE_LORA]
     else:
-        # Convert potential BaseModel items to dicts for validation
-        loras_dicts = [
-            l.model_dump() if isinstance(l, BaseModel) else l  # type: ignore[arg-type]
-            for l in loras
-        ]
-        loras_dicts = validate_loras(loras_dicts)
+        loras = validate_loras(loras)
 
     # Prepare API payload
     payload = {
         "prompt": prompt,
-        "loras": loras_dicts,
+        "loras": loras,
         "size": size,
         "num_inference_steps": num_inference_steps,
         "guidance_scale": guidance_scale,
@@ -447,13 +411,13 @@ def text_to_image(
     )
 
 
-@compliant_tool(
+@mcp.tool(
     description="""Generate an image from an existing image using WaveSpeed AI.
 
     Args:
         image (str): Required. URL, base64 string, or local file path of the input image to modify.
-        prompt (str): Required. Text description of the desired modifications. MUST BE IN ENGLISH. Non-English prompts will be rejected or result in poor quality outputs.
         images (List[str]): Required. List of URLs to images to modify.
+        prompt (str): Required. Text description of the desired modifications. MUST BE IN ENGLISH. Non-English prompts will be rejected or result in poor quality outputs.
         model (str, optional): Model to use for image generation.
         guidance_scale (float, optional): Guidance scale for text adherence. Controls how closely the output follows the prompt. Range: [1.0-10.0]. Default: 3.5.
         enable_safety_checker (bool, optional): Whether to enable safety filtering. Default: True.
@@ -480,12 +444,12 @@ def text_to_image(
 )
 def image_to_image(
     image: str,
+    images: List[str],
     prompt: str,
-    images: Optional[List[str]] = None,
     model: Optional[str] = None,
     guidance_scale: float = 3.5,
     enable_safety_checker: bool = True,
-    output_directory: Optional[str] = None,
+    output_directory: str = None,
 ):
     """Generate an image from an existing image using WaveSpeed AI."""
 
@@ -537,7 +501,7 @@ def image_to_image(
         if not image:
             image = images[0]
             payload["image"] = image
-
+            
         if not images:
             images = [image]
             payload["images"] = images
@@ -559,7 +523,7 @@ def image_to_image(
     )
 
 
-@compliant_tool(
+@mcp.tool(
     description="""Generate a video using WaveSpeed AI.
 
     Args:
@@ -597,7 +561,8 @@ def image_to_image(
         
     Note: 
         IMPORTANT: Prompts MUST be in English. The system only processes English prompts properly.
-        Non-English prompts will be rejected or produce low-quality results. Please provide English prompts directly.
+        Non-English prompts will be rejected or produce low-quality results. If user input is not in English,
+        you MUST translate it to English before passing to this tool.
     """
 )
 def generate_video(
@@ -605,7 +570,7 @@ def generate_video(
     prompt: str,
     model: Optional[str] = None,
     negative_prompt: str = "",
-    loras: Optional[List[LoraConfig]] = None,
+    loras: Optional[List[Dict[str, Union[str, float]]]] = None,
     size: str = "832*480",
     num_inference_steps: int = 30,
     duration: int = 5,
@@ -613,7 +578,7 @@ def generate_video(
     flow_shift: int = 3,
     seed: int = -1,
     enable_safety_checker: bool = True,
-    output_directory: Optional[str] = None,
+    output_directory: str = None,
 ):
     """Generate a video using WaveSpeed AI."""
 
@@ -643,13 +608,9 @@ def generate_video(
 
     # Validate and set default loras if not provided
     if not loras:
-        loras_dicts: List[Dict[str, Union[str, float]]] = []
+        loras = []
     else:
-        loras_dicts = [
-            l.model_dump() if isinstance(l, BaseModel) else l  # type: ignore[arg-type]
-            for l in loras
-        ]
-        loras_dicts = validate_loras(loras_dicts)
+        loras = validate_loras(loras)
 
     if duration not in [5, 10]:
         error_result = WaveSpeedResult(
@@ -674,7 +635,7 @@ def generate_video(
         "image": processed_image,
         "prompt": prompt,
         "negative_prompt": negative_prompt,
-        "loras": loras_dicts,
+        "loras": loras,
         "size": size,
         "num_inference_steps": num_inference_steps,
         "duration": duration,
